@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2017 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -156,20 +156,8 @@ void IconSettings::getIconReccord(){
     iconPath = iconRec.value("icon_path");
 
     if (!iconPath.isEmpty()){
-        if (QFile(iconPath).exists()){
-            cmdGetIcon->setIcon (QIcon(iconPath));
-        } else {
-            QIcon ico = CoreLib->loadIcon(iconPath);
-
-            // Do not work due to: https://bugreports.qt-project.org/browse/QTBUG-999
-            //if (ico.isNull()){
-            if (ico.availableSizes().isEmpty()){
-                ico = CoreLib->loadIcon("application-x-ms-dos-executable");
-                iconPath="";
-            }
-
-            cmdGetIcon->setIcon(ico);
-        }
+        QIcon ico = CoreLib->loadAppIcon(iconPath);
+        cmdGetIcon->setIcon(ico);
     }
 
     txtDesc->setText(iconRec.value("desc"));
@@ -356,7 +344,7 @@ void IconSettings::cmdGetProgram_Click(){
       dialog.setWindowTitle(tr("Open Exe file"));
       dialog.setDirectory(searchPath);
       dialog.setFileMode(QFileDialog::ExistingFile);
-      dialog.setNameFilter(tr("Exe, MSI, BAT files (*.exe *.msi *.bat);;Exe files (*.exe);;MSI files (*.msi);;BAT files (*.bat)"));
+      dialog.setNameFilter(tr("Exe, MSI, BAT files (*.exe *.EXE *.msi *.MSI *.bat *.BAT);;Exe files (*.exe *.EXE);;MSI files (*.msi *.MSI);;BAT files (*.bat *.BAT);;All files (*)"));
 
 
 #if QT_VERSION >= 0x040500
@@ -431,9 +419,9 @@ void IconSettings::cmdGetIcon_Click(){
       dialog.setDirectory(searchPath);
 
         #ifndef WITH_ICOUTILS
-        dialog.setNameFilter(tr("Image files (*.png *.jpg *.gif *.bmp *.xpm *.svg *.svgz)"));
+        dialog.setNameFilter(tr("Image files (*.png *.PNG *.jpg *.JPG *.gif *.GIF *.bmp *.BMP *.xpm *.XPM *.svg *.SVG *.svgz *.SVGZ)"));
         #else
-        dialog.setNameFilter(tr("Image and Win32 binary files (*.png *.jpg *.gif *.bmp *.xpm *.exe *.dll);;Image files (*.png *.jpg *.gif *.bmp *.xpm *.svg *.svgz);;Win32 Executable (*.exe);;Win32 Shared libraries (*.dll);;Win32 Executable and Shared libraries (*.exe *.dll)"));
+        dialog.setNameFilter(tr("Image and Win32 binary files (*.png *.PNG *.jpg *.JPG *.gif *.GIF *.bmp *.BMP *.xpm *.XPM *.exe *.EXE *.dll *.DLL);;Image files (*.png *.PNG *.jpg *.JPG *.gif *.GIF *.bmp *.BMP *.xpm *.XPM *.svg *.SVG *.svgz *.SVGZ);;Win32 Executable (*.exe *.EXE);;Win32 Shared libraries (*.dll *.DLL);;Win32 Executable and Shared libraries (*.exe *.EXE *.dll *.DLL);;All files (*)"));
         #endif
       //dialog.setSidebarUrls(add_prefix_urls);
 
