@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2017 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -153,7 +153,7 @@ void LoggingWidget::clearLogs(void){
     return;
 }
 
-void LoggingWidget::treeWidget_itemClicked (QTreeWidgetItem * item, int colum){
+void LoggingWidget::treeWidget_itemClicked (QTreeWidgetItem * item, int column){
     if (!item){
         logExport->setEnabled(false);
         logDelete->setEnabled(false);
