@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2017 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -238,7 +238,7 @@ void PrefixConfigWidget::getPrefixes(){
     cbPrefixes->addItems (list);
 }
 
-void PrefixConfigWidget::treeWidget_itemClicked (QTreeWidgetItem * item, int colum){
+void PrefixConfigWidget::treeWidget_itemClicked (QTreeWidgetItem * item, int column){
     this->provider = "";
     this->subtype = "";
 
