@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2017 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -610,10 +610,10 @@ void PrefixTreeWidget::menuMount_triggered(QAction* action){
 
           QString fileFilter;
 #ifdef _OS_LINUX_
-    fileFilter = tr("Disc image files (*.iso *.nrg *.img *.bin *.mdf)");
+    fileFilter = tr("Disc image files (*.iso *.ISO *.nrg *.NRG *.img *.IMG *.bin *.BIN *.mdf *.MDF);;All files (*)");
 #endif
 #ifdef _OS_FREEBSD_
-    fileFilter =  tr("ISO image files (*.iso)");
+    fileFilter =  tr("ISO image files (*.iso *.ISO);;All files (*)");
 #endif
 
 #if QT_VERSION >= 0x040500
