@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2017 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -75,18 +75,45 @@ QList<QStringList> corelib::getWineProcessList(const QString prefix_name){
     // Getting directories one by one
     for (int i = 0; i < list.size(); ++i) {
         QFileInfo fileInfo = list.at(i);
+        QFileInfo info(QString("%1/exe").arg(fileInfo.filePath()));
+        if (info.isSymLink()) {
+            QString fileName = info.symLinkTarget();
+#ifdef DEBUG
+            qDebug()<< "Traget for: " << info.filePath() << " is: " << fileName;
+#endif
+            if ((!fileName.contains("wine") && !fileName.contains(".exe")) || fileName.contains(APP_SHORT_NAME)){
+                continue;
+            }
+        } else {
+            continue;
+        }
+        name = "";
         path = "/proc/";
         path.append(fileInfo.fileName());
-        path.append("/comm");
+        path.append("/cmdline");
         QFile file_c(path);
         if (file_c.open(QIODevice::ReadOnly | QIODevice::Text)){
             // Try to read com file
             QTextStream in(&file_c);
-            QString name = in.readLine();
+            QString comm_char;
+            while (true) {
+                comm_char = in.read(1).toLatin1();
+                if ((comm_char.isNull()) or (comm_char == "\n")){
+                    break;
+                }
+                if (comm_char.isEmpty()){
+                    name.append(" ");
+                } else {
+                    name.append(comm_char);
+                }
+            }
+            //Remove args
+            name = name.split(" ")[0];
 #ifdef DEBUG
             qDebug()<<"path: "<<fileInfo.fileName()<<" comm: "<<name;
 #endif
-            if ((name.contains("wine") || name.contains(".exe")) && !name.contains(APP_SHORT_NAME)){
+
+
                 path = "/proc/";
                 path.append(fileInfo.fileName());
                 path.append("/stat");
@@ -98,10 +125,10 @@ QList<QStringList> corelib::getWineProcessList(const QString prefix_name){
                     if (!line.isNull()){
                         // Getting nice and name of the process
                         nice = line.section(' ', 18, 18);
-                        name = line.section(' ', 1, 1);
-                        name.remove(QChar('('));
-                        name.remove(QChar(')'));
-                        name = name.toLower();
+
+                        //Remove path
+                        name = name.split("/").last();
+                        name = name.split("\\").last();
 
                         path = "/proc/";
                         path.append(fileInfo.fileName());
@@ -139,7 +166,6 @@ QList<QStringList> corelib::getWineProcessList(const QString prefix_name){
                     }
                     file_s.close();
                 }
-            }
             file_c.close();
         }
     }
@@ -360,7 +386,27 @@ void corelib::checkSettings(){
 QIcon corelib::loadIcon(QString iconName, bool fromTheme){
     // Function tryes to load icon image from theme dir
     // If it fails -> load default from rsource file
-    return QIcon::fromTheme(iconName, QIcon(QString(":%1").arg(iconName)));
+    return QIcon::fromTheme(iconName, QIcon(QString(":/%1").arg(iconName)));
+}
+
+QIcon corelib::loadAppIcon(QString iconName){
+    // Function tryes to load icon image from theme dir
+    // If it fails -> load default from rsource file
+    QIcon ico;
+
+    if (QFile(iconName).exists()){
+        ico = QIcon(iconName);
+    } else {
+        ico = QIcon::fromTheme(iconName, QIcon(QString(":/%1").arg(iconName)));
+#if QT_VERSION >= 0x050700
+            if (ico.isNull()){
+#else
+            if (ico.availableSizes().isEmpty()){
+#endif
+                return loadIcon("application-x-ms-dos-executable");
+            }
+    }
+    return ico;
 }
 
 QPixmap corelib::loadPixmap(QString iconName){
@@ -1554,30 +1600,65 @@ QStringList corelib::getCdromDevices(void) const{
                         return;
                     }
 
-                    QHash<QString, QString> prefix_info = db_prefix.getByName(prefix_name);
 
-                    QStringList sh_args;
-                    sh_args << "env";
-                    sh_args << QString("WINEPREFIX=%1").arg(prefix_info.value("path"));
-                    if (!prefix_info.value("libs").isEmpty())
-                        sh_args << QString("WINEDLLPATH=%1").arg(prefix_info.value("libs"));
-                    sh_args << QString("WINELOADER=%1").arg(prefix_info.value("loader"));
-                    sh_args << QString("WINESERVER=%1").arg(prefix_info.value("server"));
-                    if (!prefix_info.value("arch").isEmpty())
-                        sh_args << QString("WINEARCH=%1").arg(prefix_info.value("arch"));
+                    // Start shell
+                    {
+                        QHash<QString, QString> prefix_info = db_prefix.getByName(prefix_name);
+                        QStringList sh_args;
+                        sh_args << "env";
 
-                    QString prefix_path=path;
-                    prefix_path.replace("'", "'\\''");
+                        sh_args << QString("WINEPREFIX='%1'").arg(getStrictEscapeString(prefix_info.value("path")));
+                        if (!prefix_info.value("server").isEmpty()){
+                            sh_args << QString("WINE='%1'").arg(getStrictEscapeString(prefix_info.value("bin")));
+                            if (!prefix_info.value("libs").isEmpty())
+                                sh_args << QString("WINEDLLPATH='%1'").arg(getStrictEscapeString(prefix_info.value("libs")));
+                            sh_args << QString("WINELOADER='%1'").arg(getStrictEscapeString(prefix_info.value("loader")));
+                            sh_args << QString("WINESERVER='%1'").arg(getStrictEscapeString(prefix_info.value("server")));
+                        } else {
+                            QString prefixDllPath;
+                            Version vers;
+                            vers.id_ = prefix_info.value("version_id");
+                            if (vers.load()){
+                                if (prefix_info.value("arch") == "win32"){
+                                    prefixDllPath = vers.wine_dllpath32_;
+                                } else if (prefix_info.value("arch") == "win64"){
+                                    prefixDllPath = vers.wine_dllpath64_;
+                                } else {
+                                    if (vers.wine_dllpath64_.isEmpty()){
+                                        prefixDllPath = vers.wine_dllpath32_;
+                                    } else {
+                                        prefixDllPath = vers.wine_dllpath64_;
+                                    }
+                                }
+                                sh_args << QString("WINE='%1'").arg(getStrictEscapeString(vers.wine_exec_));
+                                if (!prefixDllPath.isEmpty())
+                                    sh_args << QString("WINEDLLPATH='%1'").arg(getStrictEscapeString(prefixDllPath));
+                                sh_args << QString("WINELOADER='%1'").arg(getStrictEscapeString(vers.wine_loader_));
+                                sh_args << QString("WINESERVER='%1'").arg(getStrictEscapeString(vers.wine_server_));
+                            }
+                        }
 
-                    sh_args << "/bin/sh" << "-c" << QString("\"cd \'%1\' && echo \'\' && echo \' [ii] wine environment variables are set to \\\"%2\\\" prefix settings.\' && echo \'\' && %3 \"").arg(prefix_path).arg(prefix_name).arg(shell);
+                        if (!prefix_info.value("arch").isEmpty())
+                            sh_args << QString("WINEARCH=%1").arg(prefix_info.value("arch"));
 
-                    args << sh_args.join(" ");
+                        QString prefix_path = path;
+                        prefix_path.replace("'", "'\\''");
+
+                        sh_args 
+                            << "/bin/sh" 
+                            << "-c" 
+                            << QString("\"echo \'\\n\\tq4wine: wine environment variables are set to \\\"%2\\\" prefix settings.\\n\' && %3 \"")
+                                .arg(prefix_name)
+                                .arg(shell);
+
+                        args << sh_args.join(" ");
 #ifdef DEBUG
-                    qDebug()<<"[ii] Open console args:"<<args;
+                        qDebug()<<"[ii] Open console args:"<<args;
 #endif
 
-                    QProcess proc;
-                    proc.startDetached(console, args, QDir::homePath());
+                        QProcess proc;
+                        proc.startDetached(console, args, path);
+                    }
                 }
 
         void corelib::updateRecentImagesList(const QString media) const{
