@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2016 by Alexey S. Malakhov <brezerk@gmail.com>     *
+ *   Copyright (C) 2008-2017 by Oleksii S. Malakhov <brezerk@gmail.com>    *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -83,6 +83,7 @@
 #include "dir.h"
 #include "icon.h"
 #include "image.h"
+#include "versions.h"
 
 /*!
  * \class corelib
@@ -139,6 +140,7 @@ public:
     void checkSettings(void);
 
     QIcon loadIcon(QString iconName, bool fromTheme = true);
+    QIcon loadAppIcon(QString iconName);
     QPixmap loadPixmap(QString pixmapName);
 
     QString getTranslationLang();
